@@ -48,8 +48,8 @@ namespace pappso
 // Forward declaration.
 class MassSpectrum;
 
-QDataStream &operator<<(QDataStream &out, const MassSpectrum &spectrum);
-QDataStream &operator>>(QDataStream &out, MassSpectrum &spectrum);
+PMSPP_LIB_DECL QDataStream &operator<<(QDataStream &out, const MassSpectrum &spectrum);
+PMSPP_LIB_DECL QDataStream &operator>>(QDataStream &out, MassSpectrum &spectrum);
 
 typedef std::shared_ptr<MassSpectrum> MassSpectrumSPtr;
 typedef std::shared_ptr<const MassSpectrum> MassSpectrumCstSPtr;
@@ -124,3 +124,11 @@ class PMSPP_LIB_DECL MassSpectrum : public Trace
 
 
 } // namespace pappso
+
+
+Q_DECLARE_METATYPE(pappso::MassSpectrum);
+Q_DECLARE_METATYPE(pappso::MassSpectrum *);
+
+extern int massSpectrumMetaTypeId;
+extern int massSpectrumPtrMetaTypeId;
+
