@@ -500,7 +500,7 @@ QualifiedMassSpectrum::size() const
 
 
 QString
-QualifiedMassSpectrum::toString() const
+QualifiedMassSpectrum::toString(bool with_data) const
 {
   QString text;
 
@@ -540,6 +540,11 @@ QualifiedMassSpectrum::toString() const
              : -1)
       .arg(precursor_mz_values_string);
 
+  if(with_data)
+    {
+      text += msp_massSpectrum->toString();
+    }
+
   return text;
 }
 
