@@ -150,10 +150,10 @@ PwizMsFileReader::initialize()
           .arg(__LINE__));
     }
 
-  qDebug() << "The number of runs is:" << m_msDataPtrVector.size()
-           << "The reader type is:" << QString::fromStdString(readerName)
-           << "The number of spectra in first run is:"
-           << m_msDataPtrVector.at(0)->run.spectrumListPtr->size();
+  //qDebug() << "The number of runs is:" << m_msDataPtrVector.size()
+           //<< "The reader type is:" << QString::fromStdString(readerName)
+           //<< "The number of spectra in first run is:"
+           //<< m_msDataPtrVector.at(0)->run.spectrumListPtr->size();
 
   return m_msDataPtrVector.size();
 }
@@ -207,8 +207,8 @@ PwizMsFileReader::getMsRunIds(const QString &run_prefix)
             QString::fromStdString(ms_data_ptr->run.samplePtr->name));
         }
 
-      qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               << "Current ms_run_id:" << ms_run_id.toString();
+      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               //<< "Current ms_run_id:" << ms_run_id.toString();
 
       // Finally make a shared pointer out of it and append it to the vector.
       ms_run_ids.push_back(std::make_shared<MsRunId>(ms_run_id));
