@@ -28,6 +28,7 @@
 #include "timsmsfilereader.h"
 #include "../vendors/tims/timsdata.h"
 #include "../pappsoexception.h"
+#include "../exception/exceptionnotimplemented.h"
 #include <QDebug>
 #include <QFileInfo>
 
@@ -58,6 +59,14 @@ TimsMsFileReader::initialize()
       TimsData tims_data(m_fileName);
       m_fileFormat = MzFormat::brukerTims;
     }
+  catch(ExceptionNotImplemented &error)
+    {
+      m_fileFormat = MzFormat::brukerTims;
+      throw pappso::ExceptionNotImplemented(
+        QObject::tr("Error reading Bruker tims data in %1 :\n%2")
+          .arg(m_fileName)
+          .arg(error.qwhat()));
+    }
   catch(PappsoException &error)
     {
       return 0;
@@ -95,8 +104,7 @@ TimsMsFileReader::getMsRunIds(const QString &run_prefix)
 
   ms_run_id.setSampleName(QFileInfo(m_fileName).baseName());
 
-  qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-           << "Current ms_run_id:" << ms_run_id.toString();
+  qDebug() << "Current ms_run_id:" << ms_run_id.toString();
 
   // Finally make a shared pointer out of it and append it to the vector.
   ms_run_ids.push_back(std::make_shared<MsRunId>(ms_run_id));
@@ -106,9 +114,3 @@ TimsMsFileReader::getMsRunIds(const QString &run_prefix)
 
 
 } // namespace pappso
-
-
-
-
-
-
