@@ -30,7 +30,7 @@
 #include "timsmsrunreaderms2selected.h"
 #include "../../exception/exceptionnotimplemented.h"
 #include <QDebug>
-#include <QtConcurrent/QtConcurrent>
+#include <QtConcurrent>
 
 using namespace pappso;
 
