@@ -23,7 +23,10 @@
 
 #pragma once
 
-#include "obopsimod.h"
+
+
+#include "obopsimodhandlerinterface.h"
+#include "obopsimodterm.h"
 
 
 namespace pappso
