@@ -25,7 +25,10 @@
 #pragma once
 
 
-#include "obopsimod.h"
+
+#include "obopsimodhandlerinterface.h"
+#include "obopsimodterm.h"
+
 #include "../mzrange.h"
 
 namespace pappso
