@@ -23,7 +23,7 @@
 
 #pragma once
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include "../types.h"
 #include "../exportinmportconfig.h"
 #include "obopsimodterm.h"
