@@ -52,14 +52,21 @@ enum class PeptideDirection : std::int8_t
 /** \brief tells if an ion is Nter
  * \param ion_type the ion to test
  */
-bool peptideIonIsNter(PeptideIon ion_type);
+PMSPP_LIB_DECL bool peptideIonIsNter(PeptideIon ion_type);
+
+/** \brief tells if an ion type is the complement ion of the other
+ * \param ion_type_ref the ion type reference
+ * \param ion_type the ion to test
+ */
+PMSPP_LIB_DECL bool peptideIonTypeIsComplement(PeptideIon ion_type_ref,
+                                               PeptideIon ion_type);
 
 
 /** \brief get the direction of a peptide ion
  * \param ion_type the ion to test
  * \return the peptide direction
  */
-PeptideDirection getPeptideIonDirection(PeptideIon ion_type);
+PMSPP_LIB_DECL PeptideDirection getPeptideIonDirection(PeptideIon ion_type);
 
 enum class PeptideIonNter
 {
