@@ -26,6 +26,7 @@ MassDataCombinerInterface::~MassDataCombinerInterface()
 {
 }
 
+
 void
 MassDataCombinerInterface::setDecimalPlaces(int value)
 {
@@ -40,15 +41,6 @@ MassDataCombinerInterface::getDecimalPlaces() const
 }
 
 
-void
-MassDataCombinerInterface::setFilterResampleKeepXRange(
-  const FilterResampleKeepXRange &range)
-{
-  m_filterXRange        = range;
-  m_isApplyXRangeFilter = true;
-}
-
-
 MapTrace &
 MassDataCombinerInterface::combine(MapTrace &map_trace,
                                    Iterator begin,
