@@ -48,7 +48,6 @@ MassSpectrumPlusCombiner::MassSpectrumPlusCombiner(
   : MassSpectrumCombiner(other)
 
 {
-  // qDebug() << __FILE__ << " @ " << __LINE__ << __FUNCTION__ << "()";
 }
 
 
@@ -57,7 +56,6 @@ MassSpectrumPlusCombiner::MassSpectrumPlusCombiner(
   : MassSpectrumCombiner(other)
 
 {
-  // qDebug() << __FILE__ << " @ " << __LINE__ << __FUNCTION__ << "()";
 }
 
 
@@ -67,12 +65,34 @@ MassSpectrumPlusCombiner::~MassSpectrumPlusCombiner()
 }
 
 
-MapTrace &
-MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
-                                                 const Trace &trace) const
+MassSpectrumPlusCombiner &
+MassSpectrumPlusCombiner::operator=(const MassSpectrumPlusCombiner &other)
 {
-  //qDebug();
+  if(this == &other)
+    return *this;
 
+  m_decimalPlaces = other.m_decimalPlaces;
+
+  m_bins.assign(other.m_bins.begin(), other.m_bins.end());
+
+  return *this;
+}
+
+
+// We get a trace as parameter that this combiner needs to combine to the
+// map_trace we also get as parameter. This combiner is for a mass spectrum, and
+// thus it needs to have been configured to hold a vector of m/z values that are
+// bins into which DataPoints from trace are combined into map_trace. It is the
+// bins that drive the the traversal of trace. For each bin, check if there is
+// (or are, if bins are big) data points in the trace that fit in it.
+
+MapTrace &
+MassSpectrumPlusCombiner::combine(MapTrace &map_trace, const Trace &trace) const
+{
+  // qDebug();
+
+  // If there is no single point in the trace we need to combine into the
+  // map_trace, then there is nothing to do.
   if(!trace.size())
     {
       // qDebug() << "Thread:" << QThread::currentThreadId()
@@ -109,7 +129,7 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
   // Iterate in the vector of bins and for each bin check if there are matching
   // data points in the trace.
 
-  pappso_double current_bin = 0;
+  pappso_double current_bin_mz = 0;
 
   pappso_double trace_x = 0;
   pappso_double trace_y = 0;
@@ -130,10 +150,13 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
 
   while(bin_iter != bin_end_iter)
     {
-      current_bin = *bin_iter;
+      current_bin_mz = *bin_iter;
 
-      // qDebug() << "Current bin:" << QString("%1").arg(current_bin, 0, 'f',
-      // 15)
+      // std::cout << std::setprecision(10) << "current bin: " << current_bin_mz
+      //<< std::endl;
+
+      // qDebug() << "Current bin:"
+      //<< QString("%1").arg(current_bin_mz, 0, 'f', 15)
       //<< "at a distance of:"
       //<< std::distance(m_bins.begin(), bin_iter);
 
@@ -145,16 +168,21 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
       // Do not set the y value to 0 so that we can actually test if the
       // data point is valid later on (try not to push back y=0 data
       // points).
-      new_data_point.x = current_bin;
+      new_data_point.x = current_bin_mz;
 
       // Now perform a loop over the data points in the mass spectrum.
 
-      // qDebug() << "trace_iter:" << trace_iter->toString()
+      // qDebug() << "Start looping in the trace to check if its DataPoint.x "
+      //"value matches that of the current bin."
+      //<< "trace_iter:" << trace_iter->toString()
       //<< "data point distance:"
       //<< std::distance(trace_iter_begin, trace_iter);
 
       while(trace_iter != trace_iter_end)
         {
+          // std::cout << std::setprecision(10)
+          //<< "trace data point being iterated into: " << trace_iter->x
+          //<< " - " << trace_iter->y << std::endl;
 
           bool trace_matched = false;
 
@@ -169,10 +197,25 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
           //<< std::distance(trace_iter_begin, trace_iter);
 
           // if(!Utils::almostEqual(trace_iter->y, 0.0, 10))
-          if(trace_iter->y)
+
+          trace_x = trace_iter->x;
+          trace_y = trace_iter->y;
+
+          if(trace_y)
             {
-              trace_x = trace_iter->x;
-              trace_y = trace_iter->y;
+
+              // FIXME: unbelievable behaviour: when building in release mode
+              // this code, under i386 (but not x86_64), this code fails if the
+              // following cout statement is missing. There are a variety of
+              // variants that work, the common denominator being that trace_x
+              // has to be output along with a string.
+
+              // std::cout << std::setprecision(10)
+              //<< "iterated trace point: " << trace_x << " - "
+              //<< trace_y << std::endl;
+
+              // For this reason I had to deactivate the related tests
+              // for i386 in tests/test_massspectrumcombiner.cpp
 
               // trace_x is the m/z value that we need to combine,
               // so make sure we check if there is a mz shift to apply.
@@ -184,12 +227,21 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
               if(m_decimalPlaces != -1)
                 trace_x = Utils::roundToDecimals(trace_x, m_decimalPlaces);
 
-              if(trace_x <= current_bin)
+              if(trace_x <= current_bin_mz)
                 {
 
-                  // qDebug() << "Matched, increment trace_iter";
+                  // std::cout
+                  //<< std::setprecision(10)
+                  //<< "Matched, because trace point.x is <= the current "
+                  //"bin; increment trace_iter"
+                  //<< std::endl;
+
                   new_data_point.y += trace_y;
 
+                  // std::cout << std::setprecision(10)
+                  //<< "After incrementation of the intensity: "
+                  //<< new_data_point.y << std::endl;
+
                   // Let's record that we matched.
                   trace_matched = true;
 
@@ -207,6 +259,11 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
           // if(trace_iter->y)
           else
             {
+              // std::cout << std::setprecision(10)
+              //<< "itered trace point intensity is 0: " << trace_x
+              //<< " - " << trace_y << std::endl;
+
+
               // We iterated into a y=0 data point, so just skip it. Let
               // the below code think that we have matched the point and
               // iterate one step up.
@@ -249,8 +306,8 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
 
                       result.first->second += new_data_point.y;
 
-                      // qDebug() << "Incremented the data point in the map
-                      // trace.";
+                      // qDebug()
+                      //<< "Incremented the data point in the map trace.";
                     }
                   // else
                   //{
@@ -266,7 +323,7 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
             }
         }
       // End of
-      // while(1)
+      // while(trace_iter != trace_iter_end)
 
       // Each time we get here, that means that we have consumed all
       // the mass spectra data points that matched the current bin.
@@ -309,5 +366,24 @@ MassSpectrumPlusCombiner::combineNoFilteringStep(MapTrace &map_trace,
 }
 
 
+MapTrace &
+MassSpectrumPlusCombiner::combine(MapTrace &map_trace_out,
+                                  const MapTrace &map_trace_in) const
+{
+  // qDebug();
+
+  if(!map_trace_in.size())
+    {
+      // qDebug() << "Thread:" << QThread::currentThreadId()
+      //<< "Returning right away because map_trace_in is empty.";
+      return map_trace_out;
+    }
+
+  Trace trace(map_trace_in);
+
+  return combine(map_trace_out, trace);
+}
+
+
 } // namespace pappso
 
