@@ -411,7 +411,7 @@ MzIntegrationParams::createArbitraryBins()
   // Only compute the decimal places if they were not configured already.
   if(m_decimalPlaces == -1)
     {
-      // qDebug() << "Now checking how many decimal places are needed.";
+      qDebug() << "Now checking how many decimal places are needed.";
 
       // We want as many decimal places as there are 0s between the integral
       // part of the double and the first non-0 cipher.  For example, if
@@ -420,9 +420,11 @@ MzIntegrationParams::createArbitraryBins()
 
       m_decimalPlaces = pappso::Utils::zeroDecimalsInValue(binSize) + 1;
 
-      // qDebug() << "With binSize" << binSize
-      //<< " m_decimalPlaces was computed to be:" << m_decimalPlaces;
+      //qDebug() << "With binSize" << binSize
+               //<< " m_decimalPlaces was computed to be:" << m_decimalPlaces;
     }
+  //else
+    //qDebug() << "m_decimalPlaces: " << m_decimalPlaces;
 
   // Now that we have defined the value of m_decimalPlaces, let's use that
   // value.
