@@ -28,18 +28,19 @@ class PMSPP_LIB_DECL TracePlusCombiner : public TraceCombiner
 
   friend class MassSpectrumPlusCombiner;
 
-  protected:
   public:
   TracePlusCombiner();
   TracePlusCombiner(int decimal_places);
   TracePlusCombiner(const TracePlusCombiner &other);
   TracePlusCombiner(TracePlusCombinerCstSPtr other);
+
   virtual ~TracePlusCombiner();
 
   virtual MapTrace &combine(MapTrace &map_trace,
-                            const Trace &trace) const override;
-  virtual MapTrace &combine(MapTrace &map_trace_out,
-                            const MapTrace &map_trace_in) const override;
+                                           const Trace &trace) const override;
+
+  MapTrace &combine(MapTrace &map_trace_out,
+                                   const MapTrace &map_trace_in) const override;
 };
 
 
