@@ -38,18 +38,22 @@ typedef std::shared_ptr<const TracePeak> TracePeakCstSPtr;
  * */
 class PMSPP_LIB_DECL TracePeak
 {
-  protected:
-  pappso_double m_area = 0;
-  DataPoint m_max;
-  DataPoint m_left;
-  DataPoint m_right;
-
   public:
   TracePeak();
   /** @brief construct a peak given a trace, begin and end x coordinate
    */
   TracePeak(std::vector<DataPoint>::const_iterator it_begin,
             std::vector<DataPoint>::const_iterator it_end);
+
+  /** @brief construct a peak given a trace, begin and end x coordinate
+   *
+   * @param it_begin begining of trace
+   * @param it_end end of trace
+   * @param remove_base if true, remove the base peak signal
+   */
+  TracePeak(std::vector<DataPoint>::const_iterator it_begin,
+            std::vector<DataPoint>::const_iterator it_end,
+            bool remove_base);
   TracePeak(const TracePeak &other);
   ~TracePeak();
 
@@ -57,50 +61,34 @@ class PMSPP_LIB_DECL TracePeak
   TracePeakCstSPtr makeTracePeakCstSPtr() const;
 
   DataPoint &getMaxXicElement();
-  const DataPoint &
-  getMaxXicElement() const
-  {
-    return m_max;
-  };
+  const DataPoint &getMaxXicElement() const;
   void setMaxXicElement(const DataPoint &max);
 
   DataPoint &getLeftBoundary();
-  const DataPoint &
-  getLeftBoundary() const
-  {
-    return m_left;
-  };
+  const DataPoint &getLeftBoundary() const;
   void setLeftBoundary(const DataPoint &left);
 
   DataPoint &getRightBoundary();
   const DataPoint &getRightBoundary() const;
   void setRightBoundary(const DataPoint &right);
   pappso_double getArea() const;
+
+
   void setArea(pappso_double area);
 
   bool containsRt(pappso::pappso_double rt) const;
 
 
-  bool
-  operator==(const TracePeak &other) const
-  {
-    return ((m_area == other.m_area) && (m_max == other.m_max) &&
-            (m_left == other.m_left) && (m_right == other.m_right));
-  };
+  bool operator==(const TracePeak &other) const;
 
-  TracePeak &
-  operator=(const TracePeak &other)
-  {
-    if(this == &other)
-      return *this;
+  TracePeak &operator=(const TracePeak &other);
 
-    m_area  = other.m_area;
-    m_max   = other.m_max;
-    m_left  = other.m_left;
-    m_right = other.m_right;
 
-    return *this;
-  }
+  protected:
+  pappso_double m_area = 0;
+  DataPoint m_max;
+  DataPoint m_left;
+  DataPoint m_right;
 };
 
 
