@@ -63,7 +63,7 @@ FilterChargeDeconvolution::FilterChargeDeconvolution(
 
 FilterChargeDeconvolution::~FilterChargeDeconvolution()
 {
-  qInfo() << "ChargeDeconvolution destroyed";
+  qDebug() << "ChargeDeconvolution destroyed";
 }
 
 
@@ -76,7 +76,7 @@ pappso::FilterChargeDeconvolution::buildFilterFromString(
   if(strBuildParams.startsWith("chargeDeconvolution|"))
     {
       QStringList params =
-        strBuildParams.split("|").back().split(";", QString::SkipEmptyParts);
+        strBuildParams.split("|").back().split(";", Qt::SkipEmptyParts);
 
       QString precision = params.at(0);
       m_precisionPtrZ1 =
@@ -102,11 +102,19 @@ pappso::FilterChargeDeconvolution::buildFilterFromString(
 }
 
 
+QString
+pappso::FilterChargeDeconvolution::name() const
+{
+  return "chargeDeconvolution";
+}
+
+
 QString
 pappso::FilterChargeDeconvolution::toString() const
 {
   QString strCode =
-    QString("chargeDeconvolution|%1").arg(m_precisionPtrZ1->toString());
+    QString("%1|%2").arg(name()).arg(m_precisionPtrZ1->toString());
+
   strCode.replace(" ", "");
 
   return strCode;
