@@ -83,12 +83,13 @@ FilterResampleKeepGreater::operator=(const FilterResampleKeepGreater &other)
 Trace &
 FilterResampleKeepGreater::filter(Trace &spectrum) const
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__
-           << " spectrum.size()=" << spectrum.size();
+  // qDebug() << " spectrum.size()=" << spectrum.size();
+
   auto last_it = findFirstGreaterX(spectrum.begin(), spectrum.end(), m_value);
   spectrum.erase(spectrum.begin(), last_it);
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__
-           << " spectrum.size()=" << spectrum.size();
+
+  // qDebug() <<  " spectrum.size()=" << spectrum.size();
+
   return spectrum;
 }
 
@@ -166,28 +167,30 @@ FilterResampleKeepXRange::operator=(const FilterResampleKeepXRange &other)
 Trace &
 FilterResampleKeepXRange::filter(Trace &spectrum) const
 {
-  qDebug() << "The range to keep:" << m_minX << "-" << m_maxX;
+  // qDebug() << "The range to keep:" << m_minX << "-" << m_maxX;
 
   auto begin_it =
     findFirstEqualOrGreaterX(spectrum.begin(), spectrum.end(), m_minX);
 
-  qDebug() << "Found begin iterator (for m_minX) having:" << begin_it->x
-           << "x (m/z) value";
+  // qDebug() << "Found begin iterator (for m_minX) having:" << begin_it->x
+  //<< "x (m/z) value";
 
   auto end_it = findFirstGreaterX(begin_it, spectrum.end(), m_maxX);
 
   if(end_it == spectrum.end())
     {
-      qDebug() << "The end iterator (for m_maxX) is the end(). The prev "
-                  "iterator has"
-               << std::prev(end_it)->x << " x(m / z) value.";
+      // qDebug() << "The end iterator (for m_maxX) is the end(). The prev "
+      //"iterator has"
+      //<< std::prev(end_it)->x << " x(m / z) value.";
     }
   else
-    qDebug() << "Found end iterator (for m_maxX) having:" << end_it->x
-             << "x (m/z) value";
+    {
+      // qDebug() << "Found end iterator (for m_maxX) having:" << end_it->x
+      //<< "x (m/z) value";
+    }
 
-  qDebug() << "Only keeping range" << begin_it->x << "-"
-           << std::prev(end_it)->x;
+  // qDebug() << "Only keeping range" << begin_it->x << "-"
+  //<< std::prev(end_it)->x;
 
   spectrum.erase(end_it, spectrum.end());
   spectrum.erase(spectrum.begin(), begin_it);
@@ -212,9 +215,8 @@ MassSpectrumFilterResampleRemoveMzRange::
 MassSpectrum &
 MassSpectrumFilterResampleRemoveMzRange::filter(MassSpectrum &spectrum) const
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  // qDebug() << m_filterRange.filter(spectrum);
   m_filterRange.filter(spectrum);
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
   return spectrum;
 }
 
@@ -263,7 +265,7 @@ FilterResampleKeepPointInPolygon::FilterResampleKeepPointInPolygon(
 FilterResampleKeepPointInPolygon::FilterResampleKeepPointInPolygon(
   const SelectionPolygonSpecVector &selection_polygon_specs)
 {
-  qDebug();
+  // qDebug();
 
   m_selectionPolygonSpecs.assign(selection_polygon_specs.begin(),
                                  selection_polygon_specs.end());
@@ -282,7 +284,7 @@ FilterResampleKeepPointInPolygon::FilterResampleKeepPointInPolygon(
 FilterResampleKeepPointInPolygon::FilterResampleKeepPointInPolygon(
   const FilterResampleKeepPointInPolygon &other)
 {
-  qDebug();
+  // qDebug();
 
   m_selectionPolygonSpecs.assign(other.m_selectionPolygonSpecs.begin(),
                                  other.m_selectionPolygonSpecs.end());
@@ -318,8 +320,8 @@ FilterResampleKeepPointInPolygon::newSelectionPolygonSpec(
 
 
 FilterResampleKeepPointInPolygon &
-FilterResampleKeepPointInPolygon::operator=(
-  const FilterResampleKeepPointInPolygon &other)
+FilterResampleKeepPointInPolygon::
+operator=(const FilterResampleKeepPointInPolygon &other)
 {
   if(this == &other)
     return *this;
@@ -358,8 +360,8 @@ FilterResampleKeepPointInPolygon::filter(Trace &trace,
   // this FilterResampleKeepPointInPolygon filter using the
   // selection polygon specs.
 
-  qDebug() << "The lowest and greatest m/z values:" << m_lowestMz << "and"
-           << m_greatestMz;
+  // qDebug() << "The lowest and greatest m/z values:" << m_lowestMz << "and"
+  //<< m_greatestMz;
 
   // Start by filtering away all the data points outside of the
   // [m_lowestMz--m_greatestMz] range.
@@ -375,8 +377,8 @@ FilterResampleKeepPointInPolygon::filter(Trace &trace,
   auto begin_it = trace.begin();
   auto end_it   = trace.end();
 
-  qDebug() << "Iterating in the m/z range:" << begin_it->x << "-"
-           << std::prev(end_it)->x;
+  // qDebug() << "Iterating in the m/z range:" << begin_it->x << "-"
+  //<< std::prev(end_it)->x;
 
   // Start at the end of the range. The iter is outside of the requested range,
   // in fact, as shown using iter-- below.
@@ -389,7 +391,7 @@ FilterResampleKeepPointInPolygon::filter(Trace &trace,
       // to any vector item, but past the last one.
       iter--;
 
-      qDebug() << "Iterating in trace data point with m/z value:" << iter->x;
+      // qDebug() << "Iterating in trace data point with m/z value:" << iter->x;
 
       // Now that we have the m/z value, we can check it, in combination with
       // the value in the selection polygon spec (to make a point) against the
@@ -546,4 +548,3 @@ FilterResampleKeepPointInPolygon::filter(Trace &trace,
 }
 
 } // namespace pappso
-
