@@ -31,6 +31,7 @@
 #include <cstddef>
 #include "../../mzrange.h"
 #include "../../exportinmportconfig.h"
+#include "../combiners/selectionpolygon.h"
 
 namespace pappso
 {
@@ -47,6 +48,7 @@ class PMSPP_LIB_DECL FilterResampleKeepSmaller : public FilterInterface
   Trace &filter(Trace &trace) const override;
 };
 
+
 class PMSPP_LIB_DECL FilterResampleKeepGreater : public FilterInterface
 {
   private:
@@ -63,6 +65,7 @@ class PMSPP_LIB_DECL FilterResampleKeepGreater : public FilterInterface
   double getThresholdX() const;
 };
 
+
 class PMSPP_LIB_DECL FilterResampleRemoveXRange : public FilterInterface
 {
   private:
@@ -79,6 +82,7 @@ class PMSPP_LIB_DECL FilterResampleRemoveXRange : public FilterInterface
   Trace &filter(Trace &trace) const override;
 };
 
+
 class PMSPP_LIB_DECL FilterResampleKeepXRange : public FilterInterface
 {
   private:
@@ -95,6 +99,43 @@ class PMSPP_LIB_DECL FilterResampleKeepXRange : public FilterInterface
   Trace &filter(Trace &trace) const override;
 };
 
+
+using SelectionPolygonSpecVector = std::vector<SelectionPolygonSpec>;
+
+class PMSPP_LIB_DECL FilterResampleKeepPointInPolygon : public FilterInterface
+{
+  public:
+  FilterResampleKeepPointInPolygon();
+
+  FilterResampleKeepPointInPolygon(const SelectionPolygon &selection_polygon,
+                                   DataKind data_kind);
+
+  FilterResampleKeepPointInPolygon(
+    const SelectionPolygonSpecVector &selection_polygon_specs);
+
+  FilterResampleKeepPointInPolygon(
+    const FilterResampleKeepPointInPolygon &other);
+
+  virtual ~FilterResampleKeepPointInPolygon(){};
+
+  void
+  newSelectionPolygonSpec(const SelectionPolygonSpec &selection_polygon_spec);
+
+  FilterResampleKeepPointInPolygon &
+  operator=(const FilterResampleKeepPointInPolygon &other);
+
+  using FilterInterface::filter;
+
+  Trace &filter(Trace &trace) const override;
+  Trace &filter(Trace &trace, double dt_value, double rt_value) const;
+
+  private:
+  std::vector<SelectionPolygonSpec> m_selectionPolygonSpecs;
+  double m_lowestMz   = std::numeric_limits<double>::max();
+  double m_greatestMz = std::numeric_limits<double>::min();
+};
+
+
 class PMSPP_LIB_DECL MassSpectrumFilterResampleRemoveMzRange
   : public MassSpectrumFilterInterface
 {
@@ -123,4 +164,6 @@ class PMSPP_LIB_DECL MassSpectrumFilterResampleKeepMzRange
   virtual ~MassSpectrumFilterResampleKeepMzRange(){};
   MassSpectrum &filter(MassSpectrum &spectrum) const override;
 };
+
+
 } // namespace pappso
