@@ -31,6 +31,7 @@
 #include <QSettings>
 #include <QThread>
 #include <QThreadPool>
+#include <QRegularExpression>
 #include "../../exception/exceptioninterrupted.h"
 #include "../../msfile/msfileaccessor.h"
 #include "../../msrun/private/timsmsrunreaderms2.h"
@@ -168,16 +169,18 @@ TandemWrapperRun::checkXtandemVersion(const QString &tandem_bin_path)
 
   // X! TANDEM Jackhammer TPP (2013.06.15.1 - LabKey, Insilicos, ISB)
 
-  QRegExp parse_version("(.*) TANDEM ([A-Z,a-z, ]+) \\(([^ ,^\\)]*)(.*)");
+  QRegularExpression parse_version(
+    "(.*) TANDEM ([A-Z,a-z, ]+) \\(([^ ,^\\)]*)(.*)");
   qDebug() << parse_version;
   // Pattern patt = Pattern.compile("X! TANDEM [A-Z]+ \\((.*)\\)",
   //			Pattern.CASE_INSENSITIVE);
-
-  if(parse_version.exactMatch(result.constData()))
+  QRegularExpressionMatch match_parse_version =
+    parse_version.match(result.constData());
+  if(match_parse_version.hasMatch())
     {
       version_return = QString("X!Tandem %1 %2")
-                         .arg(parse_version.capturedTexts()[2])
-                         .arg(parse_version.capturedTexts()[3]); //.join(" ");
+                         .arg(match_parse_version.captured(2))
+                         .arg(match_parse_version.captured(3)); //.join(" ");
     }
   else
     {
@@ -428,6 +431,11 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
                                           pappso::FileReaderType::tims_ms2);
   origin_access.getMsRunIds();
   m_mzFormat = origin_access.getFileFormat();
+  if(m_mzFormat == pappso::MzFormat::unknown)
+    {
+      throw pappso::PappsoException(
+        QObject::tr("%1 file format not known").arg(origin));
+    }
 
   if(origin_access.getFileFormat() == pappso::MzFormat::brukerTims)
     {
