@@ -18,6 +18,7 @@
 #include "../utils.h"
 #include "../pappsoexception.h"
 #include "../exception/exceptionoutofrange.h"
+#include "../exception/exceptionnotpossible.h"
 
 
 int dataPointMetaTypeId =
@@ -54,7 +55,9 @@ DataPoint::DataPoint(std::pair<pappso_double, pappso_double> pair)
 
 DataPoint::DataPoint(const QString &text)
 {
-  initialize(text);
+  if(!initialize(text))
+    throw ExceptionNotPossible(
+      "Failed to initialize the DataPoint object using the provided string.");
 }
 
 
