@@ -6,6 +6,7 @@
 
 #include <QDataStream>
 
+#include <QMetaType>
 
 #include "../exportinmportconfig.h"
 #include "../types.h"
@@ -52,8 +53,8 @@ struct PMSPP_LIB_DECL DataPoint
   QString toString(int decimals) const;
 };
 
-QDataStream &operator<<(QDataStream &out, const DataPoint &dataPoint);
-QDataStream &operator>>(QDataStream &out, DataPoint &dataPoint);
+PMSPP_LIB_DECL QDataStream &operator<<(QDataStream &out, const DataPoint &dataPoint);
+PMSPP_LIB_DECL QDataStream &operator>>(QDataStream &out, DataPoint &dataPoint);
 } // namespace pappso
 
 Q_DECLARE_METATYPE(pappso::DataPoint);
