@@ -1,5 +1,6 @@
 #include <numeric>
 #include <limits>
+#include <qnamespace.h>
 #include <vector>
 #include <map>
 #include <cmath>
@@ -10,6 +11,7 @@
 #include <QDebug>
 #include <QObject>
 
+#include "../utils.h"
 #include "trace.h"
 #include "maptrace.h"
 #include "../processing/combiners/tracepluscombiner.h"
@@ -127,7 +129,6 @@ findDifferentYvalue(std::vector<DataPoint>::iterator begin,
                     const double &y_value)
 {
   return std::find_if(begin, end, [y_value](const DataPoint &to_compare) {
-
     if(to_compare.y != y_value)
       {
         return true;
@@ -143,7 +144,6 @@ findDifferentYvalue(std::vector<DataPoint>::const_iterator begin,
                     const double &y_value)
 {
   return std::find_if(begin, end, [y_value](const DataPoint &to_compare) {
-
     if(to_compare.y != y_value)
       {
         return true;
@@ -446,6 +446,12 @@ Trace::Trace()
 }
 
 
+Trace::Trace(const QString &text)
+{
+  initialize(text);
+}
+
+
 Trace::Trace(const std::vector<pappso_double> &xVector,
              const std::vector<pappso_double> &yVector)
 {
@@ -453,6 +459,32 @@ Trace::Trace(const std::vector<pappso_double> &xVector,
 }
 
 
+size_t
+Trace::initialize(const QString space_sep_text)
+{
+  QStringList string_list = space_sep_text.split("\n", Qt::SkipEmptyParts);
+
+  //qDebug() << "Split text into" << string_list.size()
+           //<< "substrings:" << string_list;
+  ;
+
+  for(int iter = 0; iter < string_list.size(); ++iter)
+    {
+      QString line = string_list.at(iter);
+      //qDebug() << "Now processing line:" << line;
+
+      // Returns a string that has whitespace removed from the start and the
+      // end, and that has each sequence of internal whitespace replaced with a
+      // single space.
+      line = line.simplified();
+
+      append(DataPoint(line));
+    }
+
+  return size();
+}
+
+
 Trace::Trace(
   const std::vector<std::pair<pappso_double, pappso_double>> &dataPoints)
 {
@@ -505,8 +537,7 @@ Trace::Trace(const Trace &other) : std::vector<DataPoint>(other)
 }
 
 
-Trace::Trace(const Trace &&other)
-  : std::vector<DataPoint>(std::move(other))
+Trace::Trace(const Trace &&other) : std::vector<DataPoint>(std::move(other))
 {
   // This constructor used by the MassSpectrum && constructor.
 }
@@ -980,6 +1011,33 @@ Trace::unique()
 }
 
 
+std::size_t
+Trace::removeZeroYDataPoints()
+{
+  qDebug();
+
+  auto it     = begin();
+  auto end_it = end();
+
+  std::size_t count = 0;
+
+  while(it != end_it)
+    {
+      if(Utils::almostEqual(it->y, 0))
+        {
+          // erase returns an iterator to the next item in the vector.
+          it = erase(it);
+          ++count;
+        }
+      else
+        // We need to increment (no call to erase here).
+        ++it;
+    }
+
+  return count;
+}
+
+
 QString
 Trace::toString() const
 {
