@@ -155,6 +155,7 @@ class PMSPP_LIB_DECL Trace : public std::vector<DataPoint>
 
   public:
   Trace();
+  Trace(const QString &text);
   Trace(const std::vector<pappso_double> &xVector,
         const std::vector<pappso_double> &yVector);
   Trace(const std::vector<std::pair<pappso_double, pappso_double>> &dataPoints);
@@ -168,6 +169,8 @@ class PMSPP_LIB_DECL Trace : public std::vector<DataPoint>
   size_t initialize(const std::vector<pappso_double> &xVector,
                     const std::vector<pappso_double> &yVector);
 
+  size_t initialize(const QString space_sep_text);
+
   size_t initialize(const Trace &other);
 
   size_t initialize(const std::map<pappso_double, pappso_double> &map);
@@ -206,6 +209,7 @@ class PMSPP_LIB_DECL Trace : public std::vector<DataPoint>
   void sortX();
   void sortY();
   void unique();
+  std::size_t removeZeroYDataPoints();
 
   /** @brief apply a filter on this trace
    * @param filter to process the signal
