@@ -110,9 +110,9 @@ Utils::zeroDecimalsInValue(pappso_double value)
         }
     }
 
-  //qDebug() << "Returning count:" << count;
+  //qDebug() << "Returning count:" << count - 1;
 
-  return count;
+  return count - 1;
 }
 
 
