@@ -106,6 +106,12 @@ class PMSPP_LIB_DECL Utils
    * @return QString "TRUE" or "FALSE"
    */
   static QString booleanToString(bool value);
+
+  /** @brief Convenience function to return a string describing the MzFormat of
+   * a file
+   * @return QString like "brukerTims" for enum value MzFormat::brukerTims.
+   */
+  static QString mzFormatAsString(MzFormat mz_format);
 };
 
 } // namespace pappso
