@@ -30,9 +30,7 @@
 #include "../../exception/exceptioninterrupted.h"
 #include "../../processing/combiners/tracepluscombiner.h"
 #include "../../processing/filters/filtertriangle.h"
-#include "../../processing/filters/filterpass.h"
 #include "../../processing/filters/filtersuitestring.h"
-#include "./xicextractor/timsdirectxicextractor.h"
 #include <QDebug>
 #include <solvers.h>
 #include <QSqlError>
@@ -101,21 +99,18 @@ TimsData::TimsData(QDir timsDataDirectory)
   qDebug();
 
   // get number of precursors
+  m_totalNumberOfPrecursors = 0;
   if(!q.exec("SELECT COUNT( DISTINCT Id) FROM Precursors;"))
     {
-      qDebug();
-      throw PappsoException(
-        QObject::tr("ERROR in TIMS sqlite database file %1, executing SQL "
-                    "command %2:\n%3\n%4\n%5")
-          .arg(m_timsDataDirectory.absoluteFilePath("analysis.tdf"))
-          .arg(q.lastQuery())
-          .arg(qdb.lastError().databaseText())
-          .arg(qdb.lastError().driverText())
-          .arg(qdb.lastError().nativeErrorCode()));
+      m_hasPrecursorTable = false;
     }
-  if(q.next())
+  else
     {
-      m_totalNumberOfPrecursors = q.value(0).toLongLong();
+      m_hasPrecursorTable = true;
+      if(q.next())
+        {
+          m_totalNumberOfPrecursors = q.value(0).toLongLong();
+        }
     }
 
 
@@ -413,8 +408,8 @@ TimsData::getMassSpectrumCstSPtrByRawIndex(std::size_t raw_index)
   catch(PappsoException &error)
     {
       throw PappsoException(
-        QObject::tr(
-          "Error TimsData::getMassSpectrumCstSPtrByRawIndex raw_index=%1 :\n%2")
+        QObject::tr("Error TimsData::getMassSpectrumCstSPtrByRawIndex "
+                    "raw_index=%1 :\n%2")
           .arg(raw_index)
           .arg(error.qwhat()));
     }
@@ -624,6 +619,14 @@ TimsData::getMassSpectrumCstSPtr(std::size_t timsId, std::size_t scanNum)
   return frame->getMassSpectrumCstSPtr(scanNum);
 }
 
+
+std::size_t
+TimsData::getTotalNumberOfFrames() const
+{
+  return m_totalNumberOfFrames;
+}
+
+
 std::size_t
 TimsData::getTotalNumberOfScans() const
 {
@@ -882,7 +885,7 @@ TimsData::getQualifiedMassSpectrumByRawIndex(
 
 
 Trace
-TimsData::getTicChromatogram()
+TimsData::getTicChromatogram() const
 {
   // In the Frames table, each frame has a record describing the
   // SummedIntensities for all the mobility spectra.
@@ -934,7 +937,8 @@ TimsData::getTicChromatogram()
           throw PappsoException(
             QObject::tr(
               "ERROR in TIMS sqlite database file: could not read either the "
-              "retention time or the summed intensities (%1, database name %2, "
+              "retention time or the summed intensities (%1, database name "
+              "%2, "
               "executing SQL "
               "command %3:\n%4\n%5\n%6")
               .arg(m_timsDataDirectory.absoluteFilePath("analysis.tdf"))
@@ -950,8 +954,8 @@ TimsData::getTicChromatogram()
 
       if(!res.second)
         {
-          // One other same rt value was seen already (like in ion mobility mass
-          // spectrometry, for example). Only increment the y value.
+          // One other same rt value was seen already (like in ion mobility
+          // mass spectrometry, for example). Only increment the y value.
 
           res.first->second += sumY;
         }
@@ -968,7 +972,7 @@ void
 TimsData::getQualifiedMs1MassSpectrumByPrecursorId(
   const MsRunIdCstSPtr &msrun_id,
   QualifiedMassSpectrum &mass_spectrum,
-  SpectrumDescr &spectrum_descr,
+  const SpectrumDescr &spectrum_descr,
   bool want_binary_data)
 {
 
@@ -1191,19 +1195,19 @@ pappso::TimsData::getXicCoordTimsFromPrecursorId(std::size_t precursor_id,
 
           // We proceed in this way:
 
-          // 1. For each Precursor reference to the Precursors table's ID found
-          // in the PasefFrameMsMsInfo table, store the precursor ID for
+          // 1. For each Precursor reference to the Precursors table's ID
+          // found in the PasefFrameMsMsInfo table, store the precursor ID for
           // step 2.
 
           // 2. From the Precursors table's ID from step 1, get the
           // MonoisotopicMz.
 
-          // 3. From the PasefFrameMsMsInfo table, for the Precursors table's ID
-          // reference, get a reference to the Frames table's ID. Thanks to the
-          // Frames ID, look for the Time value (acquisition retention time) for
-          // the MS/MS spectrum. The Time value in the Frames tables always
-          // corresponds to a Frame of MsMsType 8 (that is, MS/MS), which is
-          // expected since we are looking into MS/MS data.
+          // 3. From the PasefFrameMsMsInfo table, for the Precursors table's
+          // ID reference, get a reference to the Frames table's ID. Thanks to
+          // the Frames ID, look for the Time value (acquisition retention
+          // time) for the MS/MS spectrum. The Time value in the Frames tables
+          // always corresponds to a Frame of MsMsType 8 (that is, MS/MS),
+          // which is expected since we are looking into MS/MS data.
 
           // 4. From the PasefFrameMsMsInfo table, associate the values
           // ScanNumBegin and ScanNumEnd, the mobility bins in which the
@@ -1412,7 +1416,7 @@ void
 TimsData::getQualifiedMs2MassSpectrumByPrecursorId(
   const MsRunIdCstSPtr &msrun_id,
   QualifiedMassSpectrum &mass_spectrum,
-  SpectrumDescr &spectrum_descr,
+  const SpectrumDescr &spectrum_descr,
   bool want_binary_data)
 {
   try
@@ -1627,6 +1631,13 @@ pappso::TimsData::ms2ReaderSpectrumCollectionByMsLevel(
   unsigned int ms_level)
 {
   qDebug() << " ms_level=" << ms_level;
+  if(!m_hasPrecursorTable)
+    {
+      throw PappsoException(
+        QObject::tr("unable to read spectrum list : this data file does not "
+                    "contain MS2 data, no precursor found."));
+    }
+
   QSqlDatabase qdb          = openDatabaseConnection();
   QSqlQuery qprecursor_list = qdb.exec(QString(
     "SELECT PasefFrameMsMsInfo.Frame, "    // 0
@@ -1676,12 +1687,13 @@ pappso::TimsData::ms2ReaderSpectrumCollectionByMsLevel(
   qDebug() << "qprecursor_list.isSelect()=" << qprecursor_list.isSelect();
   bool first = true;
   SpectrumDescr spectrum_descr;
-  std::size_t i = 0;      /*
-                             while(qprecursor_list.next())
-                             {
-                             qDebug() << "i=" << i;
-                             i++;
-                             }*/
+  /*
+std::size_t i = 0;
+while(qprecursor_list.next())
+                         {
+                         qDebug() << "i=" << i;
+                         i++;
+                         }*/
   qprecursor_list.last(); // strange bug : get the last sql record and get
   // back, unless it will not retrieve all records.
 
@@ -1747,7 +1759,7 @@ pappso::TimsData::ms2ReaderSpectrumCollectionByMsLevel(
       // qDebug() << "qprecursor_list.executedQuery()="
       //         << qprecursor_list.executedQuery();
       // qDebug() << "qprecursor_list.last()=" << qprecursor_list.last();
-      i++;
+      // i++;
     }
   while(qprecursor_list.next());
 
@@ -1794,9 +1806,10 @@ pappso::TimsData::ms2ReaderSpectrumCollectionByMsLevel(
 
 
       std::function<std::vector<QualifiedMassSpectrum>(
-        pappso::TimsData::SpectrumDescr &)>
-        generate_spectrum = [itself, msrun_id, pointer_handler, ms_level](
-                              pappso::TimsData::SpectrumDescr &spectrum_descr)
+        const pappso::TimsData::SpectrumDescr &)>
+        map_function_generate_spectrum =
+          [itself, msrun_id, pointer_handler, ms_level](
+            const pappso::TimsData::SpectrumDescr &spectrum_descr)
         -> std::vector<QualifiedMassSpectrum> {
         std::vector<QualifiedMassSpectrum> mass_spectrum_list;
         itself->ms2ReaderGenerateMS1MS2Spectrum(msrun_id,
@@ -1809,28 +1822,35 @@ pappso::TimsData::ms2ReaderSpectrumCollectionByMsLevel(
         return mass_spectrum_list;
       };
 
+      std::function<void(
+        std::size_t,
+        const std::vector<QualifiedMassSpectrum> &qualified_spectrum_list)>
+        reduce_function_spectrum_list =
+          [pointer_handler, local_filepath](
+            std::size_t res,
+            const std::vector<QualifiedMassSpectrum> &qualified_spectrum_list) {
+            for(auto &qualified_spectrum : qualified_spectrum_list)
+              {
+                pointer_handler->setQualifiedMassSpectrum(qualified_spectrum);
+              }
+
+            if(pointer_handler->shouldStop())
+              {
+                qDebug() << "The operation was cancelled. Breaking the loop.";
+                throw ExceptionInterrupted(
+                  QObject::tr("reading TimsTOF job on %1 cancelled by the user")
+                    .arg(local_filepath));
+              }
+            res++;
+          };
+
+
       QFuture<std::size_t> res;
       res = QtConcurrent::mappedReduced<std::size_t>(
         spectrum_description_list.begin(),
         spectrum_description_list.end(),
-        generate_spectrum,
-        [pointer_handler, res, local_filepath](
-          std::size_t &result,
-          std::vector<QualifiedMassSpectrum> qualified_spectrum_list) {
-          for(auto &qualified_spectrum : qualified_spectrum_list)
-            {
-              pointer_handler->setQualifiedMassSpectrum(qualified_spectrum);
-            }
-
-          if(pointer_handler->shouldStop())
-            {
-              qDebug() << "The operation was cancelled. Breaking the loop.";
-              throw ExceptionInterrupted(
-                QObject::tr("reading TimsTOF job cancelled by the user :\n%1")
-                  .arg(local_filepath));
-            }
-          result++;
-        },
+        map_function_generate_spectrum,
+        reduce_function_spectrum_list,
         QtConcurrent::OrderedReduce);
       res.waitForFinished();
     }
@@ -1844,7 +1864,7 @@ pappso::TimsData::ms2ReaderGenerateMS1MS2Spectrum(
   const MsRunIdCstSPtr &msrun_id,
   std::vector<QualifiedMassSpectrum> &qualified_mass_spectrum_list,
   pappso::SpectrumCollectionHandlerInterface &handler,
-  pappso::TimsData::SpectrumDescr &spectrum_descr,
+  const pappso::TimsData::SpectrumDescr &spectrum_descr,
   unsigned int ms_level)
 {
 
@@ -2080,6 +2100,12 @@ pappso::TimsData::rawReaderSpectrumCollectionByMsLevel(
   unsigned int ms_level)
 {
 
+  if(!m_hasPrecursorTable)
+    {
+      throw PappsoException(
+        QObject::tr("unable to read spectrum list : this data file does not "
+                    "contain MS2 data, no precursor found."));
+    }
 
   // We'll need it to perform the looping in the spectrum list.
   std::size_t spectrum_list_size = getTotalNumberOfScans();
@@ -2114,7 +2140,6 @@ pappso::TimsData::rawReaderSpectrumCollectionByMsLevel(
     "ORDER BY PasefFrameMsMsInfo.Frame, PasefFrameMsMsInfo.ScanNumBegin ;"));
   if(qprecursor_list.lastError().isValid())
     {
-
       throw PappsoException(
         QObject::tr("ERROR in TIMS sqlite database file %1, executing SQL "
                     "command %2:\n%3\n%4\n%5")
@@ -2216,7 +2241,8 @@ pappso::TimsData::rawReaderSpectrumCollectionByMsLevel(
                       // we are in
                       has_a_precursor = true;
                     }
-                } // end to determine if we are in a precursor for this spectrum
+                } // end to determine if we are in a precursor for this
+                  // spectrum
 
               QualifiedMassSpectrum mass_spectrum;
 
@@ -2316,7 +2342,7 @@ pappso::TimsData::rawReaderSpectrumCollectionByMsLevel(
 }
 
 std::map<quint32, quint32>
-pappso::TimsData::getRawMsBySpectrumIndex(std::size_t spectrum_index)
+TimsData::getRawMsBySpectrumIndex(std::size_t spectrum_index)
 {
 
   qDebug() << " spectrum_index=" << spectrum_index;
@@ -2329,4 +2355,13 @@ pappso::TimsData::getRawMsBySpectrumIndex(std::size_t spectrum_index)
     raw_spectrum, coordinate.second, coordinate.second);
   return raw_spectrum;
 }
+
+
+const std::vector<FrameIdDescr> &
+TimsData::getFrameIdDescrList() const
+{
+  return m_frameIdDescrList;
+}
+
+
 } // namespace pappso
