@@ -49,6 +49,14 @@ class TimsData;
  */
 typedef std::shared_ptr<TimsData> TimsDataSp;
 
+
+struct PMSPP_LIB_DECL FrameIdDescr
+{
+  std::size_t m_frameId;   // frame id
+  std::size_t m_size;      // frame size (number of TOF scans in frame)
+  std::size_t m_cumulSize; // cumulative size
+};
+
 /**
  * @todo write docs
  */
@@ -85,6 +93,10 @@ class PMSPP_LIB_DECL TimsData
   pappso::MassSpectrumCstSPtr getMassSpectrumCstSPtr(std::size_t timsId,
                                                      std::size_t scanNum);
 
+  /** @brief Get total number of frames
+   */
+  std::size_t getTotalNumberOfFrames() const;
+
   /** @brief get the total number of scans
    */
   std::size_t getTotalNumberOfScans() const;
@@ -109,7 +121,7 @@ class PMSPP_LIB_DECL TimsData
                                           std::size_t spectrum_index,
                                           bool want_binary_data);
 
-  Trace getTicChromatogram();
+  Trace getTicChromatogram() const;
 
   struct SpectrumDescr
   {
@@ -129,13 +141,13 @@ class PMSPP_LIB_DECL TimsData
   void
   getQualifiedMs2MassSpectrumByPrecursorId(const MsRunIdCstSPtr &msrun_id,
                                            QualifiedMassSpectrum &mass_spectrum,
-                                           SpectrumDescr &spectrum_descr,
+                                           const SpectrumDescr &spectrum_descr,
                                            bool want_binary_data);
 
   void
   getQualifiedMs1MassSpectrumByPrecursorId(const MsRunIdCstSPtr &msrun_id,
                                            QualifiedMassSpectrum &mass_spectrum,
-                                           SpectrumDescr &spectrum_descr,
+                                           const SpectrumDescr &spectrum_descr,
                                            bool want_binary_data);
 
   /** @brief filter interface to apply just after raw MS2 specturm extraction
@@ -237,6 +249,8 @@ class PMSPP_LIB_DECL TimsData
    */
   void setMonoThread(bool is_mono_thread);
 
+  const std::vector<FrameIdDescr> &getFrameIdDescrList() const;
+
 
   private:
   SpectrumDescr getSpectrumDescrWithScanCoordinate(
@@ -277,18 +291,16 @@ class PMSPP_LIB_DECL TimsData
   void fillFrameIdDescrList();
 
 
-  private:
   void ms2ReaderGenerateMS1MS2Spectrum(
     const MsRunIdCstSPtr &msrun_id,
     std::vector<QualifiedMassSpectrum> &qualified_mass_spectrum_list,
     SpectrumCollectionHandlerInterface &handler,
-    SpectrumDescr &spectrum_descr,
+    const SpectrumDescr &spectrum_descr,
     unsigned int ms_level);
 
   void fillSpectrumDescriptionWithSqlRecord(SpectrumDescr &spectrum_descr,
                                             QSqlQuery &qprecursor_list);
 
-  private:
   QDir m_timsDataDirectory;
   TimsBinDec *mpa_timsBinDec = nullptr;
   // QSqlDatabase *mpa_qdb      = nullptr;
@@ -315,14 +327,6 @@ class PMSPP_LIB_DECL TimsData
   MzCalibrationStore *mpa_mzCalibrationStore;
 
 
-  struct FrameIdDescr
-  {
-    std::size_t m_frameId;   // frame id
-    std::size_t m_size;      // frame size (number of TOF scans in frame)
-    std::size_t m_cumulSize; // cumulative size
-  };
-
-
   /** @brief store every frame id and corresponding sizes
    */
   std::vector<FrameIdDescr> m_frameIdDescrList;
@@ -341,6 +345,8 @@ class PMSPP_LIB_DECL TimsData
 
   bool m_isMonoThread = false;
 
+  bool m_hasPrecursorTable;
+
   QMutex m_mutex;
 };
 } // namespace pappso
