@@ -30,7 +30,6 @@
 #include <memory>
 #include <QByteArray>
 #include <vector>
-#include "../../massspectrum/qualifiedmassspectrum.h"
 #include "timsframebase.h"
 #include "../../xic/xic.h"
 #include "../../msrun/xiccoord/xiccoordtims.h"
@@ -96,16 +95,23 @@ class TimsFrame : public TimsFrameBase
                                      std::size_t scanNumBegin,
                                      std::size_t scanNumEnd) const override;
 
+  virtual quint64 cumulateSingleScanIntensities(std::size_t scanNum) const override;
+  
+  virtual quint64
+  cumulateScansIntensities(std::size_t scanNumBegin,
+                           std::size_t scanNumEnd) const override;
 
   /** @brief get raw index list for one given scan
    * index are not TOF nor m/z, just index on digitizer
    */
-  virtual std::vector<quint32> getScanIndexList(std::size_t scanNum) const;
+  virtual std::vector<quint32>
+  getScanIndexList(std::size_t scanNum) const override;
 
   /** @brief get raw intensities without transformation from one scan
    * it needs intensity normalization
    */
-  virtual std::vector<quint32> getScanIntensities(std::size_t scanNum) const;
+  virtual std::vector<quint32>
+  getScanIntensities(std::size_t scanNum) const override;
 
   /** @brief get the mass spectrum corresponding to a scan number
    * @param scanNum the scan number to retrieve
