@@ -29,7 +29,9 @@
 #include "../../../pappsomspp/exception/exceptionoutofrange.h"
 #include "mzcalibration/mzcalibrationmodel1.h"
 #include <QDebug>
+#include <QObject>
 #include <cmath>
+#include <algorithm>
 
 namespace pappso
 {
@@ -120,6 +122,12 @@ TimsFrameBase::getNbrPeaks(std::size_t scanNum) const
       .arg(scanNum));
 }
 
+std::size_t
+TimsFrameBase::getTotalNumberOfScans() const
+{
+  return m_scanNumber;
+}
+
 MassSpectrumSPtr
 TimsFrameBase::getMassSpectrumSPtr(std::size_t scanNum) const
 {
@@ -138,6 +146,7 @@ TimsFrameBase::cumulateScanToTrace(std::size_t scanNumBegin,
       .arg(scanNumBegin)
       .arg(scanNumEnd));
 }
+
 void
 TimsFrameBase::cumulateScansInRawMap(std::map<quint32, quint32> &rawSpectrum
                                      [[maybe_unused]],
@@ -151,6 +160,34 @@ TimsFrameBase::cumulateScansInRawMap(std::map<quint32, quint32> &rawSpectrum
       .arg(scanNumBegin)
       .arg(scanNumEnd));
 }
+
+
+quint64
+TimsFrameBase::cumulateSingleScanIntensities(std::size_t scanNum) const
+{
+  throw PappsoException(
+    QObject::tr(
+      "ERROR unable to cumulateSingleScanIntensities in TimsFrameBase for scan "
+      "number %1.").arg(scanNum));
+  
+  return 0;
+}
+
+
+quint64
+TimsFrameBase::cumulateScansIntensities(std::size_t scanNumBegin,
+                                        std::size_t scanNumEnd) const
+{
+  throw PappsoException(
+    QObject::tr(
+      "ERROR unable to cumulateScansInRawMap in TimsFrameBase for scan "
+      "number begin %1 end %2")
+      .arg(scanNumBegin)
+      .arg(scanNumEnd));
+
+  return 0;
+}
+
 void
 TimsFrameBase::setTime(double time)
 {
@@ -383,11 +420,11 @@ TimsFrameBase::getTraceFromCumulatedScansBuiltinCentroid(
               data_point_cumul.y *= 100.0 / m_accumulationTime;
 
 
-              //qDebug() << "raw data x=" << data_point_cumul.x;
+              // qDebug() << "raw data x=" << data_point_cumul.x;
               // mz calibration
               data_point_cumul.x =
                 mz_calibration_p->getMzFromTofIndex(data_point_cumul.x);
-              //qDebug() << "mz=" << data_point_cumul.x;
+              // qDebug() << "mz=" << data_point_cumul.x;
               local_trace.push_back(data_point_cumul);
             }
 
@@ -449,4 +486,105 @@ TimsFrameBase::setMzCalibrationInterfaceSPtr(
   msp_mzCalibration = mzCalibration;
 }
 
+
+quint32
+TimsFrameBase::getMaximumRawMassIndex() const
+{
+  quint32 max_value = 0;
+  for(quint32 i = 0; i < m_scanNumber; i++)
+    {
+      qDebug() << "m_scanNumber=" << m_scanNumber << " i=" << i;
+      std::vector<quint32> index_list = getScanIndexList(i);
+      auto it = std::max_element(index_list.begin(), index_list.end());
+      if(it != index_list.end())
+        {
+          max_value = std::max(max_value, *it);
+        }
+    }
+  return max_value;
+}
+
+std::vector<quint32>
+TimsFrameBase::getScanIndexList(std::size_t scanNum) const
+{
+  throw PappsoException(
+    QObject::tr(
+      "ERROR unable to getScanIndexList in TimsFrameBase for scan number %1")
+      .arg(scanNum));
+}
+
+
+std::vector<quint32>
+TimsFrameBase::getScanIntensities(std::size_t scanNum) const
+{
+  throw PappsoException(
+    QObject::tr(
+      "ERROR unable to getScanIntensities in TimsFrameBase for scan number %1")
+      .arg(scanNum));
+}
+
+Trace
+TimsFrameBase::getIonMobilityTraceByMzIndexRange(
+  std::size_t mz_index_lower_bound,
+  std::size_t mz_index_upper_bound,
+  XicExtractMethod method) const
+{
+  Trace im_trace;
+  DataPoint data_point;
+  for(quint32 i = 0; i < m_scanNumber; i++)
+    {
+      data_point.x = i;
+      data_point.y = 0;
+      qDebug() << "m_scanNumber=" << m_scanNumber << " i=" << i;
+      std::vector<quint32> index_list = getScanIndexList(i);
+      auto it_lower                   = std::find_if(index_list.begin(),
+                                   index_list.end(),
+                                   [mz_index_lower_bound](quint32 to_compare) {
+                                     if(to_compare < mz_index_lower_bound)
+                                       {
+                                         return false;
+                                       }
+                                     return true;
+                                   });
+
+
+      if(it_lower == index_list.end())
+        {
+        }
+      else
+        {
+
+
+          auto it_upper =
+            std::find_if(index_list.begin(),
+                         index_list.end(),
+                         [mz_index_upper_bound](quint32 to_compare) {
+                           if(mz_index_upper_bound >= to_compare)
+                             {
+                               return false;
+                             }
+                           return true;
+                         });
+          std::vector<quint32> intensity_list = getScanIntensities(i);
+          for(int j = std::distance(index_list.begin(), it_lower);
+              j < std::distance(index_list.begin(), it_upper);
+              j++)
+            {
+              if(method == XicExtractMethod::sum)
+                {
+                  data_point.y += intensity_list[j];
+                }
+              else
+                {
+                  data_point.y =
+                    std::max((double)intensity_list[j], data_point.y);
+                }
+            }
+        }
+      im_trace.push_back(data_point);
+    }
+  qDebug();
+  return im_trace;
+}
+// namespace pappso
 } // namespace pappso
