@@ -76,6 +76,17 @@ class TimsFrameBase
    */
   virtual std::size_t getNbrPeaks(std::size_t scanNum) const;
 
+  /** @brief get the number of scans contained in this frame
+   * each scan represents an ion mobility slice
+   */
+
+  virtual std::size_t getTotalNumberOfScans() const;
+
+
+  /** @brief get the maximum raw mass index contained in this frame
+   */
+  virtual quint32 getMaximumRawMassIndex() const;
+
   /** @brief get Mass spectrum with peaks for this scan number
    * need the binary file
    * @param scanNum scan number in the frame in the order it lies in binary
@@ -85,6 +96,8 @@ class TimsFrameBase
 
   /** @brief cumulate spectrum given a scan number range
    * need the binary file
+   * The intensities are normalized with respect to the frame accumulation time
+   *
    * @param scanNumBegin scan number in the frame in the order it lies in binary
    * file, from 0 to N-1
    * @param scanNumEnd scan number in the frame in the order it lies in binary
@@ -95,6 +108,9 @@ class TimsFrameBase
 
 
   /** @brief cumulate scan list into a trace into a raw spectrum map
+   * The intensities are NOT normalized with respect to the frame accumulation
+   * time
+   *
    * @param rawSpectrum simple map of integers to cumulate raw counts
    * @param scanNumBegin scan number in the frame in the order it lies in binary
    * file, from 0 to N-1
@@ -105,6 +121,11 @@ class TimsFrameBase
                                      std::size_t scanNumBegin,
                                      std::size_t scanNumEnd) const;
 
+  virtual quint64 cumulateSingleScanIntensities(std::size_t scanNum) const;
+
+  virtual quint64 cumulateScansIntensities(std::size_t scanNumBegin,
+                                           std::size_t scanNumEnd) const;
+
   /** @brief check that this scan number exists
    * @param scanNum scan number in the frame in the order it lies in binary
    * file, from 0 to N-1
@@ -191,6 +212,29 @@ class TimsFrameBase
 
   void setMzCalibrationInterfaceSPtr(MzCalibrationInterfaceSPtr mzCalibration);
 
+
+  /** @brief get raw index list for one given scan
+   * index are not TOF nor m/z, just index on digitizer
+   */
+  virtual std::vector<quint32> getScanIndexList(std::size_t scanNum) const;
+
+  /** @brief get raw intensities without transformation from one scan
+   * it needs intensity normalization
+   */
+  virtual std::vector<quint32> getScanIntensities(std::size_t scanNum) const;
+
+  /** @brief get a mobility trace cumulating intensities inside the given mass
+   * index range
+   * @param mz_index_lower_bound raw mass index lower bound
+   * @param mz_index_upper_bound raw mass index upper bound
+   * @param method max or sum intensities
+   */
+  virtual Trace
+  getIonMobilityTraceByMzIndexRange(std::size_t mz_index_lower_bound,
+                                    std::size_t mz_index_upper_bound,
+                                    XicExtractMethod method) const;
+
+
   protected:
   /** @brief total number of scans contained in this frame
    */
