@@ -118,6 +118,8 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
   virtual void mouseReleaseHandlerLeftButton();
   virtual void mouseReleaseHandlerRightButton();
 
+  virtual void mouseWheelHandler(QWheelEvent *event);
+
   virtual void mouseMoveHandler(QMouseEvent *event);
   virtual void mouseMoveHandlerNotDraggingCursor();
   virtual void mouseMoveHandlerDraggingCursor();
@@ -146,8 +148,7 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
   /// RANGE-related functions
   virtual QCPRange getRangeX(bool &found_range, int index) const;
   virtual QCPRange getRangeY(bool &found_range, int index) const;
-  QCPRange
-  getRange(Axis axis, RangeType range_type, bool &found_range) const;
+  QCPRange getRange(Axis axis, RangeType range_type, bool &found_range) const;
 
   virtual QCPRange getInnermostRangeX(bool &found_range) const;
   virtual QCPRange getOutermostRangeX(bool &found_range) const;
@@ -170,7 +171,8 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
 
   virtual void replotWithAxesRanges(QCPRange xAxisRange,
                                     QCPRange yAxisRange,
-                                    Axis whichAxis);
+                                    Axis axis);
+
   virtual void replotWithAxisRangeX(double lower, double upper);
   virtual void replotWithAxisRangeY(double lower, double upper);
   /// PLOTTING / REPLOTTING functions
@@ -227,6 +229,8 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
 
   void mouseReleaseEventSignal(const BasePlotContext &context);
 
+  void mouseWheelEventSignal(const BasePlotContext &context);
+
   void plottableSelectionChangedSignal(QCPAbstractPlottable *plottable_p,
                                        bool selected);
 
@@ -336,8 +340,7 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
   QPen m_pen;
 
   virtual void createAllAncillaryItems();
-  virtual void
-  update1DSelectionRectangle(bool for_integration = false);
+  virtual void update1DSelectionRectangle(bool for_integration = false);
   virtual void update2DSelectionRectangleSquare(bool for_integration = false);
   virtual void update2DSelectionRectangleSkewed(bool for_integration = false);
   virtual QString allLayerNamesToString() const;
