@@ -26,10 +26,9 @@ class PMSPP_LIB_DECL MassSpecTracePlotContext : public BasePlotContext
 
   virtual ~MassSpecTracePlotContext();
 
+  MassSpecTracePlotContext &operator=(const BasePlotContext &other);
   MassSpecTracePlotContext &operator=(const MassSpecTracePlotContext &other);
 
-  BasePlotContext m_baseContext;
-
   int m_lastZ                 = -1;
   double m_lastMz             = std::numeric_limits<double>::min();
   double m_lastTicIntensity   = std::numeric_limits<double>::min();
