@@ -109,10 +109,6 @@ class PMSPP_LIB_DECL MassSpecTracePlotWidget : public BaseTracePlotWidget
 
   void mouseReleaseEventSignal(const MassSpecTracePlotContext &context);
 
-  void newKeyPressEventSignal(pappso::DataPoint context);
-  void testKeyPressEventSignal(pappso::MassSpecTracePlotContext context);
-
-
   protected:
   mutable MassSpecTracePlotContext m_context;
 
