@@ -45,12 +45,6 @@ class MsRunXicExtractor : public MsRunXicExtractorInterface
   public:
   MsRunXicExtractor(const MsRunXicExtractor &other);
   virtual ~MsRunXicExtractor();
-  virtual XicCstSPtr getXicCstSPtr(const MzRange &mz_range,
-                                   pappso::pappso_double rt_begin,
-                                   pappso::pappso_double rt_end) override;
-
-  virtual std::vector<XicCstSPtr>
-  getXicCstSPtrList(const std::vector<MzRange> &mz_range_list) override;
 
   protected:
   MsRunXicExtractor(MsRunReaderSPtr &msrun_reader);
@@ -61,8 +55,58 @@ class MsRunXicExtractor : public MsRunXicExtractorInterface
                            pappso::pappso_double rt_begin,
                            pappso::pappso_double rt_end);
 
+  virtual void protectedExtractXicCoordSPtrList(
+    UiMonitorInterface &monitor,
+    std::vector<XicCoordSPtr>::iterator it_xic_coord_list_begin,
+    std::vector<XicCoordSPtr>::iterator it_xic_coord_list_end) override;
+
+
+  protected:
+  struct MsRunXicExtractorPoints
+  {
+    std::size_t spectrum_index;
+    double rt;
+  };
+
+  /** @brief class to read retention time points of MsRun
+   */
+  class MsRunXicExtractorReadPoints : public SpectrumCollectionHandlerInterface
+  {
+    private:
+    std::vector<MsRunXicExtractorPoints> &m_msrun_points;
+
+    public:
+    MsRunXicExtractorReadPoints(
+      std::vector<MsRunXicExtractorPoints> &msrun_points)
+      : m_msrun_points(msrun_points){};
+
+    virtual void
+    setQualifiedMassSpectrum(const QualifiedMassSpectrum &spectrum) override
+    {
+      if(spectrum.getMsLevel() == 1)
+        {
+          m_msrun_points.push_back(
+            {spectrum.getMassSpectrumId().getSpectrumIndex(),
+             spectrum.getRtInSeconds()});
+        }
+    }
+    virtual bool
+    needPeakList() const override
+    {
+      return false;
+    }
+    virtual void
+    loadingEnded() override
+    {
+    }
+  };
+
+
   protected:
   std::vector<MsRunXicExtractorPoints> m_msrun_points;
+
+  private:
+  void extractOneXicCoord(XicCoord &xic_coord);
 };
 
 
