@@ -41,97 +41,96 @@ using namespace std;
 int
 main()
 {
-
-  cout << endl << "..:: test ion direction ::.." << endl;
+  cout << std::endl << "..:: test ion direction ::.." << std::endl;
   if(getPeptideIonDirection(PeptideIon::b) != PeptideDirection::Nter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::b) != PeptideDirection::Nter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::bstar) != PeptideDirection::Nter)
     {
       cerr
         << "getPeptideIonDirection(PeptideIon::bstar) != PeptideDirection::Nter"
-        << endl;
+        << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::bo) != PeptideDirection::Nter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::bo) != PeptideDirection::Nter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::a) != PeptideDirection::Nter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::a) != PeptideDirection::Nter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::astar) != PeptideDirection::Nter)
     {
       cerr
         << "getPeptideIonDirection(PeptideIon::astar) != PeptideDirection::Nter"
-        << endl;
+        << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::ao) != PeptideDirection::Nter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::ao) != PeptideDirection::Nter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::bp) != PeptideDirection::Nter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::bp) != PeptideDirection::Nter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::c) != PeptideDirection::Nter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::c) != PeptideDirection::Nter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::y) != PeptideDirection::Cter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::y) != PeptideDirection::Cter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::ystar) != PeptideDirection::Cter)
     {
       cerr
         << "getPeptideIonDirection(PeptideIon::ystar) != PeptideDirection::Cter"
-        << endl;
+        << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::yo) != PeptideDirection::Cter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::yo) != PeptideDirection::Cter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::z) != PeptideDirection::Cter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::z) != PeptideDirection::Cter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::yp) != PeptideDirection::Cter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::yp) != PeptideDirection::Cter"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(getPeptideIonDirection(PeptideIon::x) != PeptideDirection::Cter)
     {
       cerr << "getPeptideIonDirection(PeptideIon::x) != PeptideDirection::Cter"
-           << endl;
+           << std::endl;
       return 1;
     }
 
-  cout << endl << "..:: peptide fragment init ::.." << endl;
+  cout << std::endl << "..:: peptide fragment init ::.." << std::endl;
   // http://proteus.moulon.inra.fr/w2dpage/proticdb/angular/#/peptide_hits/10053478
   Peptide peptide("DSTIPDKQITASSFYK");
   list<PeptideIon> cid_ion = PeptideFragmentIonListBase::getCIDionList();
@@ -141,12 +140,12 @@ main()
 
   while(it != frag_cid.end())
     {
-      unsigned int size = it->get()->size();
-      QString name      = it->get()->getPeptideIonName();
+      // unsigned int size = it->get()->size();
+      QString name = it->get()->getPeptideIonName();
       cout << it->get()->getSequence().toStdString() << " "
            << it->get()->getPeptideIonName().toStdString() << " "
            << it->get()->getMz(1) << " "
-           << it->get()->getFormula(1).toStdString() << endl;
+           << it->get()->getFormula(1).toStdString() << std::endl;
       it++;
     }
 
