@@ -27,7 +27,8 @@
  ******************************************************************************/
 
 // make test ARGS="-V -I 3,3"
-#define CATCH_CONFIG_MAIN
+// ./tests/catch2-only-tests [Protein] -s
+
 #include <catch2/catch.hpp>
 #include <iostream>
 
@@ -81,6 +82,12 @@ class DigestionHandler : public EnzymeProductInterface
     _peptide_list.clear();
   }
 
+  std::size_t
+  size() const
+  {
+    return _peptide_list.size();
+  };
+
   private:
   QStringList _peptide_list;
 };
@@ -212,12 +219,18 @@ TEST_CASE("Test Protein", "[Protein]")
     DigestionHandler digestion;
     qDebug() << "kinase.eat(protein_sp,digestion)";
     kinase.eat(0, protein_sp, false, digestion);
+    
+    
+    REQUIRE (digestion.size() == 243);
 
     PeptideSizeFilter peptide_size(7, 35);
     peptide_size.setSink(&digestion);
 
     qDebug() << " kinase.eat(protein_sp,peptide_size);";
+    digestion.clear();
     kinase.eat(0, protein_sp, false, peptide_size);
+    
+    REQUIRE (digestion.size() == 191);
 
     qDebug() << " modification_sink";
 
@@ -245,7 +258,9 @@ TEST_CASE("Test Protein", "[Protein]")
 
     qDebug() << " kinase.eat(protein_sp,peptide_size2mod);";
 
+    digestion.clear();
     kinase.eat(0, protein_sp, false, peptide_size2mod);
+    REQUIRE (digestion.size() == 0);
 
     qDebug() << " kinase.eat(protein_sp,peptide_size2mod) ; end";
 
@@ -286,7 +301,8 @@ TEST_CASE("Test Protein", "[Protein]")
     kinase.eat(0, fake, false, peptide_size2varmod);
 
     digestion.clear();
-    cout << std::endl << "..:: Test trypsin peptides on fake prot ::.." << std::endl;
+    cout << std::endl
+         << "..:: Test trypsin peptides on fake prot ::.." << std::endl;
     kinase.eat(0, fake, false, digestion);
 
     REQUIRE(digestion.contain("K"));
@@ -296,18 +312,30 @@ TEST_CASE("Test Protein", "[Protein]")
 
     REQUIRE(digestion.contain("VVVMAMEEK"));
 
+    REQUIRE(digestion.size() == 6);
+
     // BSA
-    cout << std::endl << "..:: Test semi tryptic peptides on BSA ::.." << std::endl;
+    cout << std::endl
+         << "..:: Test semi tryptic peptides on BSA ::.." << std::endl;
     kinase.setMiscleavage(0);
     PeptideSemiEnzyme semi_tryptic;
     semi_tryptic.setSink(&digestion);
     qDebug() << "kinase.eat(protein_sp,semi_tryptic)";
+    digestion.clear();
     kinase.eat(0, protein_sp, false, semi_tryptic);
+    
+    
+    REQUIRE(digestion.size() == 1132);
+
 
 
     qDebug() << Qt::endl << "..:: Test enzyme motif ::.." << Qt::endl;
     Enzyme motif_digest("(MAMEE[KR])([^P])");
+    digestion.clear();
     motif_digest.eat(0, fake, false, digestion);
+    REQUIRE(digestion.size() == 2);
+    REQUIRE(digestion.contain("MVVKKVVVMAMEEK"));
+    REQUIRE(digestion.contain("WVTFISLLLLFTKVHKECCVVSTQTALA"));
 
 
     // potential Nter mod +42.01056@[
@@ -345,6 +373,9 @@ TEST_CASE("Test Protein", "[Protein]")
 
     PeptideSp peptide_test = PeptideStrParser::parseString(
       "E(MOD:00429)C(MOD:00419)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
+    REQUIRE(
+      peptide_test.get()->toString().toStdString() ==
+      "E(MOD:00429)C(MOD:00419)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
     REQUIRE(modification_sink.contain(peptide_test));
     cout << peptide_test.get()->toString().toStdString() << " is present"
          << std::endl;
@@ -394,7 +425,8 @@ TEST_CASE("Test Protein", "[Protein]")
 
 
     qDebug() << "init test protein";
-    cout << std::endl << "..:: Test Protein with B and Z wildcard ::.." << std::endl;
+    cout << std::endl
+         << "..:: Test Protein with B and Z wildcard ::.." << std::endl;
 
     // BSA
     qDebug() << "init bsa with B and Z wildcard";
@@ -432,8 +464,7 @@ TEST_CASE("Test Protein", "[Protein]")
   }
 
 
-  SECTION("..:: Test digestion pipeline ::..",
-          "[DigestionPipeline]")
+  SECTION("..:: Test digestion pipeline ::..", "[DigestionPipeline]")
   {
 
     // potential Nter mod +42.01056@[
@@ -453,8 +484,7 @@ TEST_CASE("Test Protein", "[Protein]")
     Enzyme kinase;
     kinase.eat(0, fake, false, peptide_size2varmod);
 
-    PeptideSp peptide_test = PeptideStrParser::parseString(
-      "VVVMAMEEK");
+    PeptideSp peptide_test = PeptideStrParser::parseString("VVVMAMEEK");
     REQUIRE(modification_sink.contain(peptide_test));
   }
 }
