@@ -26,6 +26,8 @@
 // make test ARGS="-V -I 1,1"
 
 // ./tests/catch2-only-tests [timsframe] -s
+// ./tests/catch2-only-tests [cubicsolver] -s
+
 
 // ./tests/catch2-only-tests [timsframe] -s -a
 
@@ -34,6 +36,7 @@
 #include <QString>
 #include <iostream>
 #include <pappsomspp/vendors/tims/timsframebase.h>
+#include <pappsomspp/vendors/tims/mzcalibration/cardano.h>
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/msfile/msfileaccessor.h>
 #include <pappsomspp/msrun/private/timsmsrunreaderms2.h>
@@ -41,12 +44,113 @@
 #include <pappsomspp/pappsoexception.h>
 #include <pappsomspp/exception/exceptionnotfound.h>
 #include <pappsomspp/processing/filters/filtersuitestring.h>
+#include <solvers.h>
 #include "config.h"
 
 using namespace pappso;
 using namespace std;
 
 
+TEST_CASE("Test Cardano's cubic solver", "[cubicsolver]")
+{
+
+  // Set the debugging message formatting pattern.
+  qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
+
+  INFO("..:: Test Cardano's cubic solver begin ::..");
+  //   OboPsiMod test;
+
+
+  SECTION("Test cubic")
+  {
+
+
+    std::vector<double> X;
+    X.push_back(18);
+    X.push_back(56);
+    X.push_back(3);
+    X.push_back(2);
+
+    alglib::real_1d_array polynom_array;
+    polynom_array.setcontent(X.size(), &(X[0]));
+
+    alglib::complex_1d_array m;
+    alglib::polynomialsolverreport rep;
+
+    alglib::polynomialsolve(polynom_array, X.size() - 1, m, rep);
+
+
+    REQUIRE(m[0].x == Approx(-0.32588));
+
+    InHousePolynomialSolverResult res;
+    res = inHousePolynomialSolve(X);
+    REQUIRE(res.type == CardanoResultCase::positived);
+    // https://www.wolframalpha.com/widgets/view.jsp?id=578d50248844454e46e24e9ed230843d
+
+    REQUIRE(res.x1.real() == Approx(-0.32588));
+  }
+
+
+  SECTION("Test quadratic")
+  {
+
+
+    std::vector<double> X;
+    X.push_back(18);
+    X.push_back(56);
+    X.push_back(3);
+    // X.push_back(2);
+
+    alglib::real_1d_array polynom_array;
+    polynom_array.setcontent(X.size(), &(X[0]));
+
+    alglib::complex_1d_array m;
+    alglib::polynomialsolverreport rep;
+
+    alglib::polynomialsolve(polynom_array, X.size() - 1, m, rep);
+
+
+    REQUIRE(m[0].x == Approx(-0.3271626093));
+
+    InHousePolynomialSolverResult res;
+    res = inHousePolynomialSolve(X);
+    REQUIRE(res.type == CardanoResultCase::quadratic);
+    // https://www.wolframalpha.com/widgets/view.jsp?id=578d50248844454e46e24e9ed230843d
+
+    REQUIRE(res.x1.real() == Approx(-0.3271626093));
+  }
+
+
+  SECTION("Test line")
+  {
+
+
+    std::vector<double> X;
+    X.push_back(18);
+    X.push_back(56);
+    // X.push_back(3);
+    // X.push_back(2);
+
+    alglib::real_1d_array polynom_array;
+    polynom_array.setcontent(X.size(), &(X[0]));
+
+    alglib::complex_1d_array m;
+    alglib::polynomialsolverreport rep;
+
+    alglib::polynomialsolve(polynom_array, X.size() - 1, m, rep);
+
+
+    REQUIRE(m[0].x == Approx(-0.3214285714));
+
+    InHousePolynomialSolverResult res;
+    res = inHousePolynomialSolve(X);
+    REQUIRE(res.type == CardanoResultCase::line);
+    // https://www.wolframalpha.com/widgets/view.jsp?id=578d50248844454e46e24e9ed230843d
+
+    REQUIRE(res.x1.real() == Approx(-0.3214285714));
+  }
+}
+
 TEST_CASE("Test tims frames", "[timsframe]")
 {
 
